@@ -13,7 +13,7 @@ def crop_corners(image, box=None, **kwargs):
             values = [int(x) for x in box.split(',')]
             width = abs(values[2] - values[0])
             height = abs(values[3] - values[1])
-            if width != image.size[0] or height != image.size[1]:
+            if width and height and (width != image.size[0] or height != image.size[1]):
                 image = image.crop(values)
         except (ValueError, IndexError):
             # There's garbage in the cropping field, ignore
